@@ -12,11 +12,12 @@ class matching:
 command_list = [        #同指令中越长的匹配词越靠前
     matching(("切换绑定","更换绑定","更改绑定"),"changebind"),
     matching(("查询绑定","绑定查询","绑定列表","查绑定"),"bindlist"),
-    matching(("ship.rank","rank"),"ship_rank"),
-    matching(("bind","绑定","set"),"bind"),
-    matching(("recent","近期",),"recent"),
-    matching(("ship","单船",),"ship"),
+    matching(("ship.rank","SHIP.RANK","rank","RANK"),"ship_rank"),
+    matching(("bind","BIND","绑定","set","SET"),"bind"),
+    matching(("recent","RECENT","近期",),"recent"),
+    matching(("ship","SHIP","单船",),"ship"),
     matching(("搜船名","查船名","船名"),"searchship"),
+    matching(("help","HELP","帮助"),"help"),
 ]
 
 nations = [
