@@ -22,15 +22,12 @@ headers = {
     'Authorization': get_driver().config.api_token
 }
   
-
-    
-
 async def get_AccountInfo(qqid,info):
     try:
         url,params = '',''
         if isinstance(info,List):
             for i in info:
-                if i == 'me':
+                if str(i).lower() == 'me':
                     url = 'https://api.wows.linxun.link/public/wows/account/v2/user/info'
                     params = {
                     "server": "QQ",
@@ -62,9 +59,9 @@ async def get_AccountInfo(qqid,info):
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
-                print(params)
+                logger.info(f"{params}")
             else:
-                return '您似乎准备用游戏昵称查询水表，请检查参数中时候包含服务器和游戏昵称，以空格区分'
+                return '您似乎准备用游戏昵称查询总体水表，请检查参数中是否包含服务器和游戏昵称，以空格区分'
         else:
             return '参数似乎出了问题呢'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
@@ -74,9 +71,7 @@ async def get_AccountInfo(qqid,info):
             result = resp.json()
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-info.html")
-            print(template)
             template_data = await set_infoparams(result['data'])
-            print(template)
             content = await template.render_async(template_data)
             return await html_to_pic(content, wait=0, viewport={"width": 920, "height": 1000})
         elif result['code'] == 403:
