@@ -32,7 +32,7 @@ async def get_ShipInfo(qqid,info,bot):
         url,params = '',''
         if isinstance(info,List):
             for flag,i in enumerate(info):              #是否包含me或@，包含则调用平台接口
-                if i == 'me':
+                if str(i).lower() == 'me':
                     url = 'https://api.wows.linxun.link/public/wows/account/v2/ship/info'
                     params = {
                     "server": "QQ",
@@ -68,22 +68,22 @@ async def get_ShipInfo(qqid,info,bot):
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
-                print(params)
+                logger.info(f"{params}")
             else:
                 return '您似乎准备用游戏昵称查询单船战绩，请检查参数中是否包含服务器、游戏昵称和船名，以空格区分'
             shipList = await get_ship_byName(str(info[0]))
-            print(shipList)
+            logger.info(f"{shipList}")
             if shipList:
                 if len(shipList) < 2:
                     params["shipId"] = shipList[0][0]
                 else:
-                    msg = f'存在多条名字相似的船\n请在20秒内选择对应的序号\n=================\n'
+                    msg = f'存在多条名字相似的船\n请在20秒内选择对应的序号\n================\n'
                     flag = 0
                     for each in shipList:
                         flag += 1
                         msg += f"{flag}：{tiers[each[3]-1]} {each[1]}\n"
                     SecletProcess[qqid] = ShipSlectState(False, None, shipList)
-                    img = await text_to_pic(text=msg,width=230)
+                    img = await text_to_pic(text=msg,css_path = str(template_path/"text-ship.css"),width=250) 
                     await bot.send(MessageSegment.image(img))
                     a = 0
                     while a < 200 and not SecletProcess[qqid].state:
